.. include:: ../BADGES.rst

.. _tstoolbox_documentation:

tstoolbox
=========

This is the home page for tstoolbox.  tstoolbox is a command line program and
Python library to work with time-series.

tstoolbox should work with Python 3.6+.

Table of Contents
-----------------
.. toctree::
   :maxdepth: 2

   readme
   notebooks
   command_line
   function_summary
   contributing
   authors
   license

Other Projects
--------------
http://timcera.bitbucket.io
